@@ -46,7 +46,7 @@ class LinkUrlInline(admin.StackedInline):
 @admin.register(QRCode)
 class QRCodeAdmin(VersionAdmin):
     list_display = ('title', 'department',
-                    'get_code_url', 'get_code_image_url')
+                    'get_code_url', 'get_code_image_url', 'basic_info')
     list_filter = (('department', admin.RelatedOnlyFieldListFilter),)
     search_fields = ('title', 'department__name', 'basic_info')
     inlines = [LinkUrlInline]
